# Sample code for Veides SDK for Python

## api basic

Sample shows basic usage of Veides Api client.

To run this sample use the following:

```bash
python3 api_basic.py -i <client_id> -t <user_token> -U <api_url>
```

## stream hub basic

Sample shows basic usage of Veides Stream Hub client. 

To run this sample use the following:

```bash
python3 stream_hub_basic.py -i <client_id> -u <user_name> -t <user_token> -H <host>
```
